@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::AVAR;
 BEGIN {
-  $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.17';
+  $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.18';
 }
 
 use 5.10.0;
@@ -27,7 +27,7 @@ sub bundle_config {
     my $no_a_pre    = $args->{no_AutoPrereq} // 0;
     my $use_mm      = $args->{use_MakeMaker} // 1;
     my $use_ct      = $args->{use_CompileTests} // 1;
-    my $bugtracker  = $args->{bugtracker}  // 'github';
+    my $bugtracker  = $args->{bugtracker}  // 'rt';
     my $homepage    = $args->{homepage};
     my $repository  = $args->{repository};
     my $tracker;
